[GITHUB REPOSITORY](https://github.com/thebroskialex/SmolPyGUI)

# SmolPyGUI

SmolPyGUI is a lightweight, minimalistic GUI framework built on top of **Pygame**.  
It provides simple, fast, and intuitive tools for creating graphical interfaces in Python projects without the complexity of full-featured GUI frameworks.

---

## Installation

You can install SmolPyGUI directly from PyPI:

```bash
pip install smolpygui
```


## Examples
See example scripts [here](https://github.com/thebroskialex/SmolPyGUI/blob/main/examples)


## Screenshots
![Example Screenshot](https://github.com/thebroskialex/SmolPyGUI/blob/main/examples/images/example1.png?raw=true)
![Example Screenshot](https://github.com/thebroskialex/SmolPyGUI/blob/main/examples/images/example2.png?raw=true)


## Features

- Simple syntax and minimal boilerplate

- Built on pygame, ensuring full compatibility with game and graphics projects

- Supports buttons, text boxes, and color customization

- Easy integration into existing Pygame loops

- Lightweight and dependency-free (beyond pygame)



## Requirements

- Python 3.12 or higher

- pygame 2.0+



## License

This project is licensed under the MIT License.
See [LICENSE](https://github.com/thebroskialex/SmolPyGUI/blob/main/LICENSE) for details.



## Author

Smol (AKA. thebroskialex)

Project link: https://github.com/thebroskialex/SmolPyGUI

PyPI: https://pypi.org/project/SmolPyGUI/